==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActivePaneEventArgsDetailDescriptionMetadata } from "./WebActivePaneEventArgsDetailDescriptionMetadata";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
export let WebActivePaneEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActivePaneEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
                WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebActivePaneEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebActivePaneEventArgsDescriptionMetadata.a);
            WebActivePaneEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebActivePaneEventArgsDetail");
        }
        static d(a) {
            WebActivePaneEventArgsDescriptionMetadata.b(a);
            a.ad("WebActivePaneEventArgs", () => new WebActivePaneEventArgsDescription());
            a.ac("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
        }
    }
    WebActivePaneEventArgsDescriptionMetadata.$t = markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebActivePaneEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActivePaneEventArgsDetailDescriptionMetadata } from "./WebActivePaneEventArgsDetailDescriptionMetadata";
import { WebActivePaneEventArgsDescription } from "./WebActivePaneEventArgsDescription";
/**
 * @hidden
 */
export let WebActivePaneEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActivePaneEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebActivePaneEventArgsDescriptionMetadata.a == null) {
                WebActivePaneEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActivePaneEventArgsDescriptionMetadata.c(WebActivePaneEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebActivePaneEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebActivePaneEventArgsDescriptionMetadata.a);
            WebActivePaneEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActivePaneEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebActivePaneEventArgsDetail");
        }
        static d(a) {
            WebActivePaneEventArgsDescriptionMetadata.b(a);
            a.ae("WebActivePaneEventArgs", () => new WebActivePaneEventArgsDescription());
            a.ad("WebActivePaneEventArgs", WebActivePaneEventArgsDescriptionMetadata.a);
        }
    }
    WebActivePaneEventArgsDescriptionMetadata.$t = markType(WebActivePaneEventArgsDescriptionMetadata, 'WebActivePaneEventArgsDescriptionMetadata');
    WebActivePaneEventArgsDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDescriptionMetadata;
})();
